**Example 1: 测试创建词汇**

创建词汇

Input: 

```
tccli tci CreateVocab --cli-unfold-argument  \
    --VocabLibName testlib \
    --VocabList hello
```

Output: 
```
{
    "Response": {
        "RequestId": "5e840747-6fa4-4e78-8870-c3a5428498cf"
    }
}
```

